@@ -24,7 +24,10 @@ def main(config: dict) -> dict:
 
 		# Copy the original icon to the resource pack
 		destination: str = f"{config['build_resource_pack']}/assets/{namespace}/textures/font/original_icon.png"
-		super_copy(original_icon, destination)
+		image: Image.Image = Image.open(original_icon).convert("RGB")
+		if image.width > 256:
+			image = image.resize((256, 256))
+		image.save(destination)
 
 		# Replace every ICON text component with the original icon
 		for component in source_lore:
